<?php
	
	if (!defined('PLX_ROOT')) exit;
	
	##############################################################################################
	# ModerationList
	#
	# Ce plugin permet de gérer une liste blanche et une liste noire de visiteurs.
	#
	# Les visiteurs en liste blanche pourront commenter sans être modéré
	# Les visiteurs en liste noire ne pourront pas commenter du tout
	# Les autres visiteurs verront leurs commentaires modérés
	# 
	##############################################################################################	
	
	class ModerationList extends plxPlugin {
		public $whiteList = array();
		public $blackList = array();
		public $useWL = true;
		public $useBL = true;
		public $autoBLTimer = 30; // Time before it's not possible for human to post comment.
		// Bots who dont care this will be automatically added in BL
		// 0 to disable
		// SimpleStat is required for this plugin
		// obsolete : public $deleteBlacklisted = true; // When comment is blacklisted : delete it instead of just set to moderate
		public $saveMode = 1; // 1 = spam are saved as SPAM, 2 = spam are saved as To moderate, 3 = spam are not savecd
		public $forceModeration = false; // You can check List and moderation even if comment is posted without site url
		public $adminText = false; // Keep old style text link action (instead of new image buttons)
		public $spamPrefix = "^"; //set as ~ to merge with Akismet SPAMS
		
		// When SPAM is detected, or when you clic on BL button in admin commtent page
		public $autoAddBLIP = true;   // add IP to BL
		public $autoAddBLMail = true; // add Mail to BL
		public $autoAddBLSite = true; // add Site to BL
		
		// When you clic on WL button in admin commtent page
		public $autoAddWLIP = true;   // add IP to WL
		public $autoAddWLMail = true; // add Mail to WL
		public $autoAddWLSite = true; // add Site to WL
		
		public $blackListed = 0; // Auto blacklist counter
		public $SPAMTag = "<p><b>Ce message a été identifié comme un SPAM</b></p>";
		
		const BEGIN_CODE = '<?php' . PHP_EOL;
		const END_CODE = PHP_EOL . '?>';
		
		##############################################################################################
		#
		# Class constructor
		#
		##############################################################################################	
		public function __construct($default_lang) {
			parent::__construct($default_lang);
			$this->setConfigProfil(PROFIL_ADMIN); 
			
			// lecture de la config
			if (!empty($this->aParams)){
				if (isset($this->aParams['whiteList'])) $this->whiteList = unserialize($this->aParams['whiteList']['value']);
				if (isset($this->aParams['blackList'])) $this->blackList = unserialize($this->aParams['blackList']['value']);
				
				if (isset($this->aParams['useWL'])) $this->useWL = ($this->aParams['useWL']['value']==1);
				if (isset($this->aParams['useBL'])) $this->useBL = ($this->aParams['useBL']['value']==1);
				
				if (isset($this->aParams['autoBLTimer'])) $this->autoBLTimer = $this->aParams['autoBLTimer']['value'];
				if (isset($this->aParams['forceModeration'])) $this->forceModeration = ($this->aParams['forceModeration']['value']==1);
				if (isset($this->aParams['adminText'])) $this->adminText = ($this->aParams['adminText']['value']==1);
				//if (isset($this->aParams['deleteBlacklisted'])) $this->deleteBlacklisted = ($this->aParams['deleteBlacklisted']['value']==1);
				if (isset($this->aParams['saveMode'])) $this->saveMode = (int) $this->aParams['saveMode']['value'];
				
				if (isset($this->aParams['autoAddBLIP'])) $this->autoAddBLIP = ($this->aParams['autoAddBLIP']['value']==1);
				if (isset($this->aParams['autoAddBLMail'])) $this->autoAddBLMail = ($this->aParams['autoAddBLMail']['value']==1);
				if (isset($this->aParams['autoAddBLSite'])) $this->autoAddBLSite = ($this->aParams['autoAddBLSite']['value']==1);
				if (isset($this->aParams['autoAddWLIP'])) $this->autoAddWLIP = ($this->aParams['autoAddWLIP']['value']==1);
				if (isset($this->aParams['autoAddWLMail'])) $this->autoAddWLMail = ($this->aParams['autoAddWLMail']['value']==1);
				if (isset($this->aParams['autoAddWLSite'])) $this->autoAddWLSite = ($this->aParams['autoAddWLSite']['value']==1);
				
				if (isset($this->aParams['blackListed'])) $this->blackListed = $this->aParams['blackListed']['value'];
			}
			
			// ajout des hook
			# Sur page admin des commentaires, action de mise en WL & BL
			$this->addHook('AdminCommentsPrepend', 'AdminCommentsPrepend');
			# Sur page admin des commentaires, pour ajouter WL et BL dans le menu déroulant des actions
			$this->addHook('AdminCommentsTop', 'AdminCommentsTop');
			# Sur page admin des commentaires, pour ajouter les boutons WL et BL a coté de chaque commentaire
			$this->addHook('AdminCommentsPagination', 'AdminCommentsPagination');
			# Pour chaque commentaire envoyé, tester whitelist et blacklist
			$this->addHook('plxMotorAddCommentaire', 'plxMotorAddCommentaire');
			
			// Utiliser une variable de session pour vérifier le délai entre 2 pages
			if ($this->autoBLTimer > 0 // seulement si fonction timer activé dans la config 
			&& !isset($_POST["name"]) && !isset($_POST["content"]) && !isset($_POST["site"]) // sauf si commentaire en cours de soumission
			&& ( empty($_SESSION['msgcom']) || $_SESSION['msgcom'] == L_NEWCOMMENT_ERR || $_SESSION['msgcom'] == L_COM_IN_MODERATION)){ // sauf si un message va etre affiché au visiteur (mais sauf si le message est celui du blacklist ou modération)
				$_SESSION["ModerationListTime"] = time();
				
				# Pour ajouter un timer sur le bouton submit commentaire
				$this->addHook('ThemeEndBody', 'ThemeEndBody');
				
				}elseif (isset($_SESSION["profil"]) && $_SESSION["profil"] < 3  ){
				# Pour ajouter des boutons de modération sur les commentaires
				$this->addHook('ThemeEndBody', 'ThemeEndBody');    
			}
		} //public function __construct
		
		/**
			* Méthode qui supprime le tag "Ce message est un SPAM	 
		**/
		public function cleanBlacklistTag($comid){
			global $plxAdmin;
			$file = PLX_ROOT.$plxAdmin->aConf["racine_commentaires"].$comid.".xml";
			file_put_contents($file, str_replace($this->SPAMTag,"",file_get_contents($file)));
		} //function cleanBlacklistTag
		
		/**
			* Méthode qui permet de mettre en SPAM un commentaire
		**/
		public function SPAMCommentaire( &$id, $racineCom) {
			# Génération du nom du fichier
			$oldfilename = PLX_ROOT.$racineCom.$id.'.xml';
			if(!file_exists($oldfilename)) # Commentaire inexistant
			return plxMsg::Error(L_ERR_UNKNOWN_COMMENT);
			# Recherche id si comment modéré ou spam
			if(preg_match('/([[:punct:]]?)[0-9]{4}.[0-9]{10}-[0-9]+$/',$id,$capture)) {
				$id=str_replace($capture[1],'',$id);
			}
			$id = $this->spamPrefix.$id;
			
			# Génération du nouveau nom de fichier
			$newfilename = PLX_ROOT.$racineCom.$id.'.xml';
			# On renomme le fichier
			@rename($oldfilename,$newfilename);
			# Contrôle
			if(is_readable($newfilename)) {
				return plxMsg::Info("Mise en SPAM effectuée avec succès");
				} else {
				return plxMsg::Error(L_COMMENT_MODERATE_ERR);
			}
		} //function SPAMCommentaire
		
		/**
			* Méthode qui ajoute des éléments à la blakclist et les enleve de la whitelist si nécessaire	 
			* Elements : IP, e-mail, url site	 	 
			* Cette méthode incrémente aussi le compteur d'auto blocage
			* Synergie @SimpleStat : transmettre a SimpleStat le statut SPAMBOT	 
		**/
		public function addToBlacklist($ip,$mail,$site,$count,$datetime=false){
			include_once(PLX_CORE.'lib/class.plx.msg.php');
			
			// Synergie SimpleStat => Ecrire entrée dans log si blacklisté
			global $plxAdmin;
			global $plxMotor;
			$SimpleStat = false;
			if (isset($plxAdmin) && isset($plxAdmin->plxPlugins->aPlugins["SimpleStat"])) $SimpleStat = $plxAdmin->plxPlugins->aPlugins["SimpleStat"];
			if (isset($plxMotor) && isset($plxMotor->plxPlugins->aPlugins["SimpleStat"])) $SimpleStat = $plxMotor->plxPlugins->aPlugins["SimpleStat"];
			if ($SimpleStat){
				$date = ($datetime)?substr($datetime,0,4).'-'.substr($datetime,4,2).'-'.substr($datetime,6,2):$SimpleStat->Date;
				$hour = ($datetime)?substr($datetime,8,2).':'.substr($datetime,10,2).':00':$SimpleStat->Hour;
				$filename = $SimpleStat->DataDir . $SimpleStat->Fileprefix . $date . '.csv';
				// log visitor only if file is writable
				if (!is_file($filename) or is_writable($filename)) {
					if(!is_file($filename)) {
						$handle      = fopen($filename,'w');
					} else $handle = fopen($filename,'a');
					
					// Log the visitor in the current day log file
					fputcsv($handle,
					array(  $date,
					$hour,
					$ip,
					"",
					"spambot",
					""
					),
					';','"');
					fclose($handle);
				}
			} // if ($SimpleStat)
			
			$updated = false;
			if (!empty($ip)&& $this->autoAddBLIP &&!in_array($ip,$this->blackList)){
				$this->blackList[] = $ip;
				$updated = true;
				if (in_array($ip,$this->whiteList))
				unset($this->whiteList[ array_search($ip,$this->whiteList) ]);
			}
			$mail = strtolower($mail);
			if (!empty($mail)&& $this->autoAddBLMail &&!in_array($mail,$this->blackList)){
				$this->blackList[] = $mail;
				$updated = true;
				if (in_array($mail,$this->whiteList))
				unset($this->whiteList[ array_search($mail,$this->whiteList) ]);
			}
			$site = strtolower(trim($site,'/'));
			if (!empty($site)&& $this->autoAddBLSite &&!in_array($site,$this->blackList)){
				$this->blackList[] = $site;
				$updated = true;
				if (in_array($site,$this->whiteList))
				unset($this->whiteList[ array_search($site,$this->whiteList) ]);
			}
			
			if ($updated){
				$this->setParam('blackList', serialize($this->blackList), 'cdata');
				$this->setParam('whiteList', serialize($this->whiteList), 'cdata');
			}
			
			if (!empty($count)){
				$this->blackListed = $this->blackListed + $count;
				$this->setParam('blackListed', $this->blackListed, 'numeric');
				$updated = true;
			}
			
			if ($updated) $this->saveParams();
			
		} //function addToBlacklist
		
		/**
			* Méthode qui ajoute des éléments à la whitelist et les enleve de la blacklist si nécessaire	 
			* Elements : IP, e-mail, url site	 
		**/
		public function addToWhitelist($ip,$mail,$site){
			include_once(PLX_CORE.'lib/class.plx.msg.php');
			$updated = false;
			if (!empty($ip)&& $this->autoAddWLIP &&!in_array($ip,$this->whiteList)){
				$this->whiteList[] = $ip;
				$updated = true;
				
				if (in_array($ip,$this->blackList))
				unset($this->blackList[ array_search($ip,$this->blackList) ]);
			}
			$mail = strtolower($mail);
			if (!empty($mail)&& $this->autoAddWLMail &&!in_array($mail,$this->whiteList)){
				$this->whiteList[] = $mail;
				$updated = true;
				if (in_array($mail,$this->blackList))
				unset($this->blackList[ array_search($mail,$this->blackList) ]);
			}
			$site = strtolower(trim($site,'/'));
			if (!empty($site)&& $this->autoAddWLSite &&!in_array($site,$this->whiteList)){
				$this->whiteList[] = $site;
				$updated = true;
				if (in_array($site,$this->blackList))
				unset($this->blackList[ array_search($site,$this->blackList) ]);
			}
			
			if ($updated){
				$this->setParam('whiteList', serialize($this->whiteList), 'cdata');
				$this->setParam('blackList', serialize($this->blackList), 'cdata');
				$this->saveParams();
			}
		} //function addToWhitelist
		
		/**
			* Méthode qui ajoute les boutons WL et BL a coté de chaque commentaire
			* sur la page admin des commentaires
		**/
		public function AdminCommentsPagination() {
			echo '
			<script type="text/javascript">
			var tds = document.getElementById("comments-table");
			if (!tds) tds = document.getElementById("form_comments"); //for pluxml 5.3
			tds = tds.getElementsByTagName("td");
			for (i=4;i<tds.length;i=i+5){
			com = tds[i].childNodes[2].href
			com = com.substr(com.indexOf("?"));';
			if (!$this->adminText){ // replace 3 default actions by icones
				echo '
				tds[i].childNodes[0].innerHTML="<img src=\"'.PLX_PLUGINS.'ModerationList/img/repondre.png\" width=32 height=32>"; 
				tds[i].childNodes[2].innerHTML="<img src=\"'.PLX_PLUGINS.'ModerationList/img/modifier-comment.png\" width=32 height=32>";
				tds[i].childNodes[4].innerHTML="<img src=\"'.PLX_PLUGINS.'ModerationList/img/modifier-article.png\" width=32 height=32>";
				tds[i].removeChild(tds[i].childNodes[3]);
				tds[i].removeChild(tds[i].childNodes[1]);
				tds[i].innerHTML+="<br>";
				';
			}
			if ($this->useWL){
				if ($this->adminText){
					echo 'sep = "<?php if (substr($plxAdmin->version,0,3)<="5.3") {?> |<?php }?>";
					tds[i].innerHTML+=sep+" <a href=\""+com+"&whitelist=1"+"\" onclick=\"return confirm(\'Confirmer la mise en White List ?\');\" title=\"Ajouter le visiteur en White liste et mettre le commentaire en ligne\">WhiteList</a>";
					';
					}else{
					echo '
					tds[i].innerHTML+="<a href=\""+com+"&whitelist=1"+"\" onclick=\"return confirm(\'Confirmer la mise en White List ?\');\"><img src=\"'.PLX_PLUGINS.'ModerationList/img/whitelist.png\"  title=\"Ajouter le visiteur en White liste et mettre le commentaire en ligne\" width=32 height=32></a>";
					';      
				}
			}
			if ($this->useBL){
				if ($this->adminText){
					echo 'sep = "<?php if (substr($plxAdmin->version,0,3)=="5.3") {?> |<?php }?>";
					tds[i].innerHTML+=sep+" <a href=\""+com+"&blacklist=1"+"\" onclick=\"return confirm(\'Confirmer la mise en Black List ?\');\" title=\"Ajouter le visiteur en Black liste et '.(($this->saveMode==3)?'supprimer':'modérer').' le commentaire\">BlackList</a>";
					';
					}else{
					echo '
					tds[i].innerHTML+="<a href=\""+com+"&blacklist=1"+"\" onclick=\"return confirm(\'Confirmer la mise en Black List ?\');\"><img src=\"'.PLX_PLUGINS.'ModerationList/img/blacklist.png\" title=\"Ajouter le visiteur en Black liste et '.(($this->saveMode==3)?'supprimer':'modérer').' le commentaire\" width=32 height=32></a>";
					';
				}
			}
			echo '}';
			
			if ($_SESSION["profil"]==0) //afficher bouton goto confg seulement si user est admin
			echo '
			var ab=document.getElementsByClassName("action-bar");
			if (ab.length>0){
			ab[0].innerHTML+=\' <a href="parametres_plugin.php?p=ModerationList"><button type="button" title="Modifier manuellement WhiteList et BlackList ou accéder aux options du plugin">Configurer ModerationList</button></a>\';
			}else{
			ab=document.getElementById("id_selection1").parentNode;
			if (ab) ab.innerHTML+=\' <a href="parametres_plugin.php?p=ModerationList"><button type="button" title="Modifier manuellement WhiteList et BlackList ou accéder aux options du plugin">Configurer ModerationList</button></a>\';
			}';
			
			echo '</script>
			';
		} //function AdminCommentsPagination
		
		/**
			* Méthode qui ajoute WL et BL dans le menu déroulant des actions
			* sur la page admin des commentaires
		**/
		public function AdminCommentsTop() {	
			echo self::BEGIN_CODE;
		?>		
		$spamPrefix = '<?= $this->spamPrefix ?>';
		$selector1 =selector("all", "id_selection1");
		if((!empty($_GET["sel"]) AND $_GET["sel"]=="spam") OR (isset($_SESSION["selCom"]) AND $_SESSION["selCom"]=="spam")){
		$comSel = "spam";
		$comSelMotif = "/^\\'.$spamPrefix.'[0-9]{4}.(.*).xml$/";
		$_SESSION["selCom"] = "spam";
		$nbComPagination=$plxAdmin->nbComments($comSelMotif);
		foreach($breadcrumbs as $k=>$v) $breadcrumbs[$k]=str_replace("class=\"selected\"","",$v);
		$h2 = "<h2>Liste des SPAMS</h2>";
		if (substr($plxAdmin->version,0,3)<="5.3"){
		echo "$h2";
		$selector2 = selector("all", "id_selection2");;
        }
        
		} elseif(strpos($comSelMotif,"punct")!==false){
		$comSelMotif = "/^[_]?[0-9]{4}.(.*).xml$/";
		}
		$nbComSPAM=($comSel=="spam")?$nbComPagination:$plxAdmin->nbComments("/\\'.$spamPrefix.'[0-9]{4}.(.*).xml$/");
			
			if ($nbComSPAM>0){
			if (substr($plxAdmin->version,0,3)<="5.3"){
			$breadcrumbs[] = "<a ".($_SESSION["selCom"]=="spam"?"class=\'selected\' ":"")."href=\'comments.php?sel=spam&amp;page=1\'>Spam</a>&nbsp;(".$nbComSPAM.")";
			}else{
		    $breadcrumbs[] = "<li><a ".($_SESSION["selCom"]=="spam"?"class=\'selected\' ":"")."href=\'comments.php?sel=spam&amp;page=1\'>Spam</a>&nbsp;(".$nbComSPAM.")</li>";
			}
			}
			$selector_add = "<option value=\"-\">-----</option>";
			$selector_add .= "<option value=\"WL\">White List</option>";
			$selector_add .= "<option value=\"BL\">Black List</option>";
		$selector1 = str_replace ("</select>",$selector_add."</select>"  ,$selector1 );
		<?php
			echo self::END_CODE;
		} //function AdminCommentsTop
		
		/**
			* Méthode qui gère les actions mise en WL et mise en BL
			* sur la page admin des commentaires
		**/
		public function AdminCommentsPrepend() {
			echo '<?php
		$plxAdmin->checkProfil(PROFIL_ADMIN, PROFIL_MANAGER, PROFIL_MODERATOR);
		
		# Bouton Whitelist
		if (!empty($_GET["c"]) AND !empty($_GET["whitelist"]) ) {
		$id = $_GET["c"];
		if (in_array($id.".xml",$plxAdmin->plxGlob_coms->aFiles)){ //comment exist
		$comment = $plxAdmin->parseCommentaire(PLX_ROOT.$plxAdmin->aConf["racine_commentaires"].$id.".xml");
		$plxAdmin->plxPlugins->aPlugins["ModerationList"]->addToWhitelist($comment["ip"],$comment["mail"],$comment["site"]);
		$plxAdmin->plxPlugins->aPlugins["ModerationList"]->cleanBlacklistTag($id);
		$plxAdmin->modCommentaire($id, "online");
		}
		header("Location: comments.php".(!empty($_GET["a"])?"?a=".$_GET["a"]:""));
		exit;
		}
		# Bouton Blacklist
		if (!empty($_GET["c"]) AND !empty($_GET["blacklist"]) ) {
		$id = $_GET["c"];
		if (in_array($id.".xml",$plxAdmin->plxGlob_coms->aFiles)){ //comment exist
		$comment = $plxAdmin->parseCommentaire(PLX_ROOT.$plxAdmin->aConf["racine_commentaires"].$id.".xml");
		$plxAdmin->plxPlugins->aPlugins["ModerationList"]->addToBlacklist($comment["ip"],$comment["mail"],$comment["site"],0,$comment["date"]);
		if ($plxAdmin->plxPlugins->aPlugins["ModerationList"]->saveMode==3){
		$plxAdmin->delCommentaire($id);
		}elseif ($plxAdmin->plxPlugins->aPlugins["ModerationList"]->saveMode==2){
		$plxAdmin->modCommentaire($id, "offline");
		}else{
		$plxAdmin->plxPlugins->aPlugins["ModerationList"]->SPAMCommentaire($id,$plxAdmin->aConf["racine_commentaires"]);
		}
		}
		header("Location: comments.php".(!empty($_GET["a"])?"?a=".$_GET["a"]:""));
		exit;
		}
		# Bouton Delete
		if (!empty($_GET["c"]) AND !empty($_GET["delete"]) ) {
		$id = $_GET["c"];
		if (in_array($id.".xml",$plxAdmin->plxGlob_coms->aFiles)){ //comment exist
		$plxAdmin->delCommentaire($id);
		}
		header("Location: comments.php".(!empty($_GET["a"])?"?a=".$_GET["a"]:""));
		exit;
		}
		# Blacklist des commentaires sélectionnés
		if (isset($_POST["selection"]) AND (!empty($_POST["btn_ok1"]) AND $_POST["selection"][0]=="BL") AND isset($_POST["idCom"])) {
		foreach ($_POST["idCom"] as $k => $v){ //$v = id de commentaire
		$comment = $plxAdmin->parseCommentaire(PLX_ROOT.$plxAdmin->aConf["racine_commentaires"].$v.".xml");
		$plxAdmin->plxPlugins->aPlugins["ModerationList"]->addToBlacklist($comment["ip"],$comment["mail"],$comment["site"],0,$comment["date"]);
		if ($plxAdmin->plxPlugins->aPlugins["ModerationList"]->saveMode==3){
		$plxAdmin->delCommentaire($v);
		}elseif ($plxAdmin->plxPlugins->aPlugins["ModerationList"]->saveMode==2){
		$plxAdmin->modCommentaire($v, "offline");
		}else{
		$plxAdmin->plxPlugins->aPlugins["ModerationList"]->SPAMCommentaire($v,$plxAdmin->aConf["racine_commentaires"]);
		}
		}
		header("Location: comments.php".(!empty($_GET["a"])?"?a=".$_GET["a"]:""));
		exit;
		}
		# Whitelist des commentaires sélectionnés
		if (isset($_POST["selection"]) AND (!empty($_POST["btn_ok1"]) AND $_POST["selection"][0]=="WL") AND isset($_POST["idCom"])) {
		foreach ($_POST["idCom"] as $k => $v){ //$v = id de commentaire
		$comment = $plxAdmin->parseCommentaire(PLX_ROOT.$plxAdmin->aConf["racine_commentaires"].$v.".xml");
		$plxAdmin->plxPlugins->aPlugins["ModerationList"]->addToWhitelist($comment["ip"],$comment["mail"],$comment["site"]);
		$plxAdmin->plxPlugins->aPlugins["ModerationList"]->cleanBlacklistTag($v);
		$plxAdmin->modCommentaire($v, "online");
		}
		header("Location: comments.php".(!empty($_GET["a"])?"?a=".$_GET["a"]:""));
		exit;
		}
		
		// gestion du clic sur breadcum spam
		if(isset($GET["sel"]) && $_GET["sel"]=="spam") $_SESSION["selCom"] = "spam";
		
		?'.'>';
		} //function AdminCommentsPrepend
		
		public function plxMotorAddCommentaire(){
			echo '<?php
			if ($this->path_url=="core/admin/comment.php") return; // pas de filtrage en édition de commentaire
			if (empty($content["site"]) and !$this->plxPlugins->aPlugins["ModerationList"]->forceModeration) return; // pas de filtrage si pas durl
			// Test WhiteList
			if ($this->plxPlugins->aPlugins["ModerationList"]->useWL 
			&& ( ( !empty($content["mail"]) && in_array(strtolower(trim($content["mail"])) , $this->plxPlugins->aPlugins["ModerationList"]->whiteList) )
			|| ( !empty($content["site"]) && in_array(strtolower(trim($content["site"], " \t\n\r\0\x0B/")) , $this->plxPlugins->aPlugins["ModerationList"]->whiteList) )
			|| ( !empty($content["ip"]) && in_array($content["ip"] , $this->plxPlugins->aPlugins["ModerationList"]->whiteList) )
			)
			) {
			if ($this->aConf["mod_com"]) $content["filename"] = trim($content["filename"],"_");
			$this->aConf["mod_com"] = false;
			// Test BlackList
			} elseif ($this->plxPlugins->aPlugins["ModerationList"]->useBL 
			&& ( ( !empty($content["mail"]) && in_array(strtolower(trim($content["mail"])) , $this->plxPlugins->aPlugins["ModerationList"]->blackList) )
			|| ( !empty($content["site"]) && in_array(strtolower(trim($content["site"], " \t\n\r\0\x0B/")) , $this->plxPlugins->aPlugins["ModerationList"]->blackList) )
			|| ( !empty($content["ip"]) && in_array($content["ip"] , $this->plxPlugins->aPlugins["ModerationList"]->blackList) )
			)
			) {
			$this->plxPlugins->aPlugins["ModerationList"]->addToBlacklist($content["ip"],$content["mail"],$content["site"],1);
			if (!$this->aConf["mod_com"]) $content["filename"] = "_" . $content["filename"];
			$this->aConf["mod_com"] = true;
			if ($this->plxPlugins->aPlugins["ModerationList"]->saveMode==3) //ne pas sauvegarder
			return true; // commentaire rejeté si blacklist
			if ($this->plxPlugins->aPlugins["ModerationList"]->saveMode==1) //sauvegarder comme spam
			$content["filename"] = str_replace("_","^",$content["filename"]);
			if ($this->plxPlugins->aPlugins["ModerationList"]->saveMode==2) //sauvegarder comme modéré
			$content["content"] = $this->plxPlugins->aPlugins["ModerationList"]->SPAMTag . $content["content"]; // Ajout de la ligne "Ce commentaire est un SPAM"
			
			} else {
			// chercher si timer pas respecté => BL    
			if ($this->plxPlugins->aPlugins["ModerationList"]->autoBLTimer > 0){
			if (empty($_SESSION["ModerationListTime"]) || (time() - $_SESSION["ModerationListTime"] < $this->plxPlugins->aPlugins["ModerationList"]->autoBLTimer)){
			$this->plxPlugins->aPlugins["ModerationList"]->addToBlacklist($content["ip"],$content["mail"],$content["site"],1);         
			if (!$this->aConf["mod_com"]) $content["filename"] = "_" . $content["filename"];
			$this->aConf["mod_com"] = true;
			if ($this->plxPlugins->aPlugins["ModerationList"]->saveMode==3) //ne pas sauvegarder
			return true; // commentaire rejeté si blacklist
			if ($this->plxPlugins->aPlugins["ModerationList"]->saveMode==1) //sauvegarder comme spam
			$content["filename"] = str_replace("_","^",$content["filename"]);
			if ($this->plxPlugins->aPlugins["ModerationList"]->saveMode==2) //sauvegarder comme modéré
			$content["content"] = $this->plxPlugins->aPlugins["ModerationList"]->SPAMTag . $content["content"]; // Ajout de la ligne "Ce commentaire est un SPAM"
			}
			}
			
			// autre cas, commentaire modéré
			if (!$this->aConf["mod_com"]) $content["filename"] = "_" . $content["filename"];
			$this->aConf["mod_com"] = true;
			}
			?>';
			
		} // function plxMotorAddCommentaire
		
		public function ThemeEndBody(){
			
			echo '<?php
			if (strpos(serialize(get_included_files()),"commentaires.php")!==false){ 
			?>';
			
			if ($this->autoBLTimer > 0 // seulement si fonction timer activé dans la config 
			&& !isset($_POST["name"]) && !isset($_POST["content"]) && !isset($_POST["site"]) // sauf si commentaire en cours de soumission
			&& ( empty($_SESSION['msgcom']) || $_SESSION['msgcom'] == L_NEWCOMMENT_ERR || $_SESSION['msgcom'] == L_COM_IN_MODERATION)){ // sauf si un message va etre affiché au visiteur (mais sauf si le message est celui du blacklist ou modération)
				echo '    
				<script type="text/javascript">
				var inputs = document.getElementById("form");
				if (!inputs) inputs = document.getElementById("comments");
				if (inputs){
				inputs = inputs.getElementsByTagName("input");
				var submit=false;
				for(i=0;i<inputs.length;i++)
				if (inputs[i].type=="submit"){
				submit=inputs[i];
				break;
				}
				if (submit){
				submit.disabled=true;
				submit.plxDefVal=submit.value;
				submit.plxToWait='.$this->autoBLTimer.';
				submit.plxDefToWait = submit.plxToWait;
				submit.value= submit.plxDefVal + " ("+submit.plxToWait+")";
				submit.plxCountdown = setInterval(function () { 
				if (submit.plxToWait>1){
				submit.plxToWait--;
				submit.value= submit.plxDefVal + " ("+submit.plxToWait+")";
				submit.disabled=true;
				}else{
				submit.value= submit.plxDefVal;
				submit.disabled=false;
				//clearInterval(submit.plxCountdown);
				}
				}, 1000);
				var tagsA = document.getElementsByTagName("a");
				for (i=0;i<tagsA.length;i++)
				if (tagsA[i].id != "capcha-reload"){
				tagsA[i].onmousedown=reset_timer;
				tagsA[i].addEventListener("touchstart",reset_timer);
				}
				document.getElementsByTagName("body")[0].onfocus=reset_timer;
				}  
				}
				function reset_timer(){
				submit.plxToWait=submit.plxDefToWait+5;
			}
			</script>
			';
			}
			if(isset($_SESSION["profil"]) && $_SESSION["profil"] < 3  ){
			echo '
			<script type="text/javascript">
			var numcom = document.getElementsByClassName("nbcom");
			if (numcom.length==0) var numcom = document.getElementsByClassName("num-com");
			for (i=0;i<numcom.length;i++){
			numcom[i].parentNode.innerHTML += \'<a href="<?php echo $plxShow->plxMotor->racine; ?>core/admin/comments.php?blacklist=1&c=<?php echo $plxShow->plxMotor->cible; ?>.\'+numcom[i].href.substr(numcom[i].href.indexOf("#")+2)+\'" title="Ajouter le visiteur en Black liste et '.(($this->saveMode==3)?'supprimer':'modérer').' le commentaire" style="float:right"><img src="<?php echo $plxShow->plxMotor->racine . PLX_PLUGINS ?>ModerationList/img/blacklist.png" width=32 height=32></a><a href="<?php echo $plxShow->plxMotor->racine; ?>core/admin/comments.php?delete=1&c=<?php echo $plxShow->plxMotor->cible; ?>.\'+numcom[i].href.substr(numcom[i].href.indexOf("#")+2)+\'" title="Supprimer le commentaire" style="float:right"><img src="<?php echo $plxShow->plxMotor->racine . PLX_PLUGINS ?>ModerationList/img/delete.png" width=32 height=32></a>\';
			numcom[i].parentNode.innerHTML += \'<a href="<?php echo $plxShow->plxMotor->racine; ?>core/admin/comment.php?c=<?php echo $plxShow->plxMotor->cible; ?>.\'+numcom[i].href.substr(numcom[i].href.indexOf("#")+2)+\'" title="Editer ce commentaire" style="float:right"><img src=\"<?php echo $plxShow->plxMotor->racine . PLX_PLUGINS ?>ModerationList/img/modifier-comment.png\" width=32 height=32></a>\';
			numcom[i].parentNode.innerHTML += \'<a href="<?php echo $plxShow->plxMotor->racine; ?>core/admin/comment_new.php?c=<?php echo $plxShow->plxMotor->cible; ?>.\'+numcom[i].href.substr(numcom[i].href.indexOf("#")+2)+\'" title="Répondre" style="float:right"><img src=\"<?php echo $plxShow->plxMotor->racine . PLX_PLUGINS ?>ModerationList/img/repondre.png\" width=32 height=32></a>\';
			}
			</script>
			';
			}
			echo ' 
			<?php }
			?'.'>';
			} //function ThemeEndBody
			
			} //class ModerationList
						